@@ -33,6 +33,7 @@ var (
 
 	// Helper programs
 	groupaddCmd  = "groupadd"
+	groupmodCmd  = "groupmod"
 	groupdelCmd  = "groupdel"
 	mdadmCmd     = "mdadm"
 	mountCmd     = "mount"
@@ -90,6 +91,7 @@ func BootIDPath() string        { return bootIDPath }
 func SystemConfigDir() string   { return fromEnv("SYSTEM_CONFIG_DIR", systemConfigDir) }
 
 func GroupaddCmd() string  { return groupaddCmd }
+func GroupmodCmd() string  { return groupmodCmd }
 func GroupdelCmd() string  { return groupdelCmd }
 func MdadmCmd() string     { return mdadmCmd }
 func MountCmd() string     { return mountCmd }
@@ -141,11 +143,12 @@ func fromEnv(nameSuffix, defaultValue string) string {
 
 func bakedStringToBool(s string) bool {
 	// the linker only supports string args, so do some basic bool sensing
-	if s == "true" || s == "1" {
+	switch s {
+	case "true", "1":
 		return true
-	} else if s == "false" || s == "0" {
+	case "false", "0":
 		return false
-	} else {
+	default:
 		// if we got a bad compile flag, just crash and burn rather than assume
 		panic(fmt.Sprintf("value '%s' cannot be interpreted as a boolean", s))
 	}
